@@ -23,7 +23,8 @@ import importlib
 import logging
 import sys
 import traceback
-from typing import IO, List, Sequence, Tuple
+from collections.abc import Sequence
+from typing import IO
 
 import yaml
 
@@ -70,7 +71,6 @@ def build_argparser() -> argparse.ArgumentParser:
         The argument parser that defines the ``translate_header.py``
         command-line interface.
     """
-
     parser = argparse.ArgumentParser(description="Summarize headers from astronomical data files")
     parser.add_argument(
         "files",
@@ -275,7 +275,7 @@ def process_files(
     outstream: IO = sys.stdout,
     errstream: IO = sys.stderr,
     output_mode: str = "auto",
-) -> Tuple[List[str], List[str]]:
+) -> tuple[list[str], list[str]]:
     """Read and translate metadata from the specified files.
 
     Parameters
@@ -338,10 +338,9 @@ def main() -> int:
     Returns
     -------
     status : `int`
-        Exit status to be passed to `sys.exit()`. 0 if any of the files
-        could be translated. 1 otherwise.
+        Exit status to be passed to `sys.exit`. ``0`` if any of the files
+        could be translated. ``1`` otherwise.
     """
-
     logging.warn(
         "This command is deprecated. Please use 'astrometadata translate' "
         " or 'astrometadata dump' instead. See 'astrometadata -h' for more details."
