@@ -9,7 +9,7 @@
 # Use of this source code is governed by a 3-clause BSD-style
 # license that can be found in the LICENSE file.
 
-"""Represent standard metadata from instrument headers"""
+"""Represent standard metadata from instrument headers."""
 
 from __future__ import annotations
 
@@ -20,19 +20,8 @@ import itertools
 import json
 import logging
 import math
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    FrozenSet,
-    MutableMapping,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Type,
-)
+from collections.abc import Callable, MutableMapping, Sequence
+from typing import TYPE_CHECKING, Any
 
 import astropy.time
 from astropy.coordinates import AltAz, SkyCoord
@@ -154,13 +143,13 @@ class ObservationInfo:
 
     def __init__(
         self,
-        header: Optional[MutableMapping[str, Any]],
-        filename: Optional[str] = None,
-        translator_class: Optional[Type[MetadataTranslator]] = None,
+        header: MutableMapping[str, Any] | None,
+        filename: str | None = None,
+        translator_class: type[MetadataTranslator] | None = None,
         pedantic: bool = False,
-        search_path: Optional[Sequence[str]] = None,
-        required: Optional[Set[str]] = None,
-        subset: Optional[Set[str]] = None,
+        search_path: Sequence[str] | None = None,
+        required: set[str] | None = None,
+        subset: set[str] | None = None,
     ) -> None:
         # Initialize the empty object
         self._header: MutableMapping[str, Any] = {}
@@ -261,9 +250,9 @@ class ObservationInfo:
 
     @staticmethod
     def _get_all_properties(
-        extensions: Optional[Dict[str, PropertyDefinition]] = None
-    ) -> Dict[str, PropertyDefinition]:
-        """Return the definitions of all properties
+        extensions: dict[str, PropertyDefinition] | None = None
+    ) -> dict[str, PropertyDefinition]:
+        """Return the definitions of all properties.
 
         Parameters
         ----------
@@ -282,8 +271,8 @@ class ObservationInfo:
             properties.update({"ext_" + pp: dd for pp, dd in extensions.items()})
         return properties
 
-    def _declare_extensions(self, extensions: Optional[Dict[str, PropertyDefinition]]) -> None:
-        """Declare and set up extension properties
+    def _declare_extensions(self, extensions: dict[str, PropertyDefinition] | None) -> None:
+        """Declare and set up extension properties.
 
         This should always be called internally as part of the creation of a
         new `ObservationInfo`.
@@ -316,7 +305,7 @@ class ObservationInfo:
         self.all_properties = self._get_all_properties(extensions)
 
     def __setattr__(self, name: str, value: Any) -> Any:
-        """Set attribute
+        """Set attribute.
 
         This provides read-only protection for the extension properties. The
         core set of properties have read-only protection via the use of the
@@ -364,7 +353,7 @@ class ObservationInfo:
         return True
 
     @property
-    def cards_used(self) -> FrozenSet[str]:
+    def cards_used(self) -> frozenset[str]:
         """Header cards used for the translation.
 
         Returns
@@ -408,7 +397,10 @@ class ObservationInfo:
         return result
 
     def __eq__(self, other: Any) -> bool:
-        """Compares equal if standard properties are equal"""
+        """Check equality with another object.
+
+        Compares equal if standard properties are equal.
+        """
         if not isinstance(other, ObservationInfo):
             return NotImplemented
 
@@ -441,8 +433,8 @@ class ObservationInfo:
             return NotImplemented
         return self.datetime_begin > other.datetime_begin
 
-    def __getstate__(self) -> Tuple[Any, ...]:
-        """Get pickleable state
+    def __getstate__(self) -> tuple[Any, ...]:
+        """Get pickleable state.
 
         Returns the properties.  Deliberately does not preserve the full
         current state; in particular, does not return the full header or
@@ -459,8 +451,8 @@ class ObservationInfo:
 
         return state, self.extensions
 
-    def __setstate__(self, state: Tuple[Any, ...]) -> None:
-        """Set object state from pickle
+    def __setstate__(self, state: tuple[Any, ...]) -> None:
+        """Set object state from pickle.
 
         Parameters
         ----------
@@ -495,7 +487,7 @@ class ObservationInfo:
 
         Returns
         -------
-        simple : `dict` of [`str`, `Any`]
+        simple : `dict` of [`str`, `~typing.Any`]
             Simple dict of all properties.
 
         Notes
@@ -550,7 +542,7 @@ class ObservationInfo:
 
         Parameters
         ----------
-        simple : `dict` [`str`, `Any`]
+        simple : `dict` [`str`, `~typing.Any`]
             The dict returned by `to_simple()`
 
         Returns
@@ -574,7 +566,7 @@ class ObservationInfo:
 
         properties = cls._get_all_properties(extensions)
 
-        processed: Dict[str, Any] = {}
+        processed: dict[str, Any] = {}
         for k, v in simple.items():
             if v is None:
                 continue
@@ -615,7 +607,7 @@ class ObservationInfo:
 
     @classmethod
     def makeObservationInfo(  # noqa: N802
-        cls, *, extensions: Optional[Dict[str, PropertyDefinition]] = None, **kwargs: Any
+        cls, *, extensions: dict[str, PropertyDefinition] | None = None, **kwargs: Any
     ) -> ObservationInfo:
         """Construct an `ObservationInfo` from the supplied parameters.
 
@@ -642,7 +634,6 @@ class ObservationInfo:
             Raised if a supplied value does not match the expected type
             of the property.
         """
-
         obsinfo = cls(None)
         obsinfo._declare_extensions(extensions)
 
@@ -679,7 +670,7 @@ class ObservationInfo:
 
 
 # Method to add the standard properties
-def _make_property(property: str, doc: str, return_typedoc: str, return_type: Type) -> Callable:
+def _make_property(property: str, doc: str, return_typedoc: str, return_type: type) -> Callable:
     """Create a getter method with associated docstring.
 
     Parameters
@@ -725,7 +716,7 @@ for name, definition in PROPERTIES.items():
 
 
 def makeObservationInfo(  # noqa: N802
-    *, extensions: Optional[Dict[str, PropertyDefinition]] = None, **kwargs: Any
+    *, extensions: dict[str, PropertyDefinition] | None = None, **kwargs: Any
 ) -> ObservationInfo:
     """Construct an `ObservationInfo` from the supplied parameters.
 
