@@ -9,7 +9,7 @@
 # Use of this source code is governed by a 3-clause BSD-style
 # license that can be found in the LICENSE file.
 
-"""Classes and support code for metadata translation"""
+"""Classes and support code for metadata translation."""
 
 from __future__ import annotations
 
@@ -21,25 +21,8 @@ import logging
 import math
 import warnings
 from abc import abstractmethod
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    ClassVar,
-    Dict,
-    FrozenSet,
-    Iterable,
-    Iterator,
-    List,
-    Mapping,
-    MutableMapping,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Type,
-    Union,
-)
+from collections.abc import Callable, Iterable, Iterator, Mapping, MutableMapping, Sequence
+from typing import TYPE_CHECKING, Any, ClassVar
 
 import astropy.io.fits.card
 import astropy.units as u
@@ -57,18 +40,15 @@ log = logging.getLogger(__name__)
 CORRECTIONS_RESOURCE_ROOT = "corrections"
 
 """Cache of version strings indexed by class."""
-_VERSION_CACHE: Dict[Type, str] = dict()
+_VERSION_CACHE: dict[type, str] = dict()
 
 
-def cache_translation(func: Callable, method: Optional[str] = None) -> Callable:
-    """Decorator to cache the result of a translation method.
-
-    Especially useful when a translation uses many other translation
-    methods.  Should be used only on ``to_x()`` methods.
+def cache_translation(func: Callable, method: str | None = None) -> Callable:
+    """Cache the result of a translation method.
 
     Parameters
     ----------
-    func : `function`
+    func : `~collections.abc.Callable`
         Translation method to cache.
     method : `str`, optional
         Name of the translation method to cache.  Not needed if the decorator
@@ -77,8 +57,20 @@ def cache_translation(func: Callable, method: Optional[str] = None) -> Callable:
 
     Returns
     -------
-    wrapped : `function`
+    wrapped : `~collections.abc.Callable`
         Method wrapped by the caching function.
+
+    Notes
+    -----
+    Especially useful when a translation uses many other translation
+    methods or involves significant computation.
+    Should be used only on ``to_x()`` methods.
+
+    .. code-block:: python
+
+        @cache_translation
+        def to_detector_num(self):
+            ....
     """
     name = func.__name__ if method is None else method
 
@@ -93,7 +85,7 @@ def cache_translation(func: Callable, method: Optional[str] = None) -> Callable:
 
 
 class MetadataTranslator:
-    """Per-instrument metadata translation support
+    """Per-instrument metadata translation support.
 
     Parameters
     ----------
@@ -107,36 +99,36 @@ class MetadataTranslator:
     """
 
     # These are all deliberately empty in the base class.
-    name: Optional[str] = None
+    name: str | None = None
     """The declared name of the translator."""
 
-    default_search_path: Optional[Sequence[str]] = None
+    default_search_path: Sequence[str] | None = None
     """Default search path to use to locate header correction files."""
 
     default_resource_package = __name__.split(".")[0]
     """Module name to use to locate the correction resources."""
 
-    default_resource_root: Optional[str] = None
+    default_resource_root: str | None = None
     """Default package resource path root to use to locate header correction
     files within the ``default_resource_package`` package."""
 
-    _trivial_map: Dict[str, Union[str, List[str], Tuple[Any, ...]]] = {}
+    _trivial_map: dict[str, str | list[str] | tuple[Any, ...]] = {}
     """Dict of one-to-one mappings for header translation from standard
     property to corresponding keyword."""
 
-    _const_map: Dict[str, Any] = {}
+    _const_map: dict[str, Any] = {}
     """Dict defining a constant for specified standard properties."""
 
-    translators: Dict[str, Type] = dict()
+    translators: dict[str, type[MetadataTranslator]] = dict()
     """All registered metadata translation classes."""
 
-    supported_instrument: Optional[str] = None
+    supported_instrument: str | None = None
     """Name of instrument understood by this translation class."""
 
-    all_properties: Dict[str, PropertyDefinition] = {}
+    all_properties: dict[str, PropertyDefinition] = {}
     """All the valid properties for this translator including extensions."""
 
-    extensions: Dict[str, PropertyDefinition] = {}
+    extensions: dict[str, PropertyDefinition] = {}
     """Extension properties (`str`: `PropertyDefinition`)
 
     Some instruments have important properties beyond the standard set; this is
@@ -167,7 +159,7 @@ class MetadataTranslator:
         to_detector_num: ClassVar[Callable[[MetadataTranslator], int]]
         to_detector_name: ClassVar[Callable[[MetadataTranslator], str]]
         to_detector_serial: ClassVar[Callable[[MetadataTranslator], str]]
-        to_detector_group: ClassVar[Callable[[MetadataTranslator], Optional[str]]]
+        to_detector_group: ClassVar[Callable[[MetadataTranslator], str | None]]
         to_detector_exposure_id: ClassVar[Callable[[MetadataTranslator], int]]
         to_object: ClassVar[Callable[[MetadataTranslator], str]]
         to_temperature: ClassVar[Callable[[MetadataTranslator], u.Quantity]]
@@ -180,7 +172,7 @@ class MetadataTranslator:
         to_observation_id: ClassVar[Callable[[MetadataTranslator], str]]
 
     @classmethod
-    def defined_in_this_class(cls, name: str) -> Optional[bool]:
+    def defined_in_this_class(cls, name: str) -> bool | None:
         """Report if the specified class attribute is defined specifically in
         this class.
 
@@ -205,7 +197,7 @@ class MetadataTranslator:
         Retrieves the attribute associated with the given name.
         Then looks in all the parent classes to determine whether that
         attribute comes from a parent class or from the current class.
-        Attributes are compared using `id()`.
+        Attributes are compared using :py:func:`id`.
         """
         # The attribute to compare.
         if not hasattr(cls, name):
@@ -240,7 +232,7 @@ class MetadataTranslator:
 
         Returns
         -------
-        f : `function`
+        f : `~collections.abc.Callable`
             Function returning the constant.
         """
 
@@ -254,11 +246,16 @@ class MetadataTranslator:
             return_type = type(constant)
             property_doc = f"Returns constant value for '{property_key}' property"
 
+        if return_type.__module__ == "builtins":
+            full_name = return_type.__name__
+        else:
+            full_name = f"{return_type.__module__}.{return_type.__qualname__}"
+
         constant_translator.__doc__ = f"""{property_doc}
 
         Returns
         -------
-        translation : `{return_type}`
+        translation : `{full_name}`
             Translated property.
         """
         return constant_translator
@@ -267,12 +264,12 @@ class MetadataTranslator:
     def _make_trivial_mapping(
         cls,
         property_key: str,
-        header_key: Union[str, Sequence[str]],
-        default: Optional[Any] = None,
-        minimum: Optional[Any] = None,
-        maximum: Optional[Any] = None,
-        unit: Optional[astropy.unit.Unit] = None,
-        checker: Optional[Callable] = None,
+        header_key: str | Sequence[str],
+        default: Any | None = None,
+        minimum: Any | None = None,
+        maximum: Any | None = None,
+        unit: astropy.unit.Unit | None = None,
+        checker: Callable | None = None,
     ) -> Callable:
         """Make a translator method returning a header value.
 
@@ -302,7 +299,7 @@ class MetadataTranslator:
         unit : `astropy.units.Unit`, optional
             If not `None`, the value read from the header will be converted
             to a `~astropy.units.Quantity`.  Only supported for numeric values.
-        checker : `function`, optional
+        checker : `~collections.abc.Callable`, optional
             Callback function to be used by the translator method in case the
             keyword is not present.  Function will be executed as if it is
             a method of the translator class.  Running without raising an
@@ -311,7 +308,7 @@ class MetadataTranslator:
 
         Returns
         -------
-        t : `function`
+        t : `~collections.abc.Callable`
             Function implementing a translator with the specified
             parameters.
         """
@@ -397,7 +394,7 @@ class MetadataTranslator:
         ``_trivialMap`` can be defined.  Trivial mappings are a dict mapping a
         generic property to either a header keyword, or a tuple consisting of
         the header keyword and a dict containing key value pairs suitable for
-        the `MetadataTranslator.quantity_from_card()` method.
+        the `MetadataTranslator.quantity_from_card` method.
         """
         super().__init_subclass__(**kwargs)
 
@@ -439,7 +436,7 @@ class MetadataTranslator:
                     "%s: %s is defined explicitly but will be replaced %s", cls.__name__, name, location
                 )
 
-        properties = set(PROPERTIES) | set(("ext_" + pp for pp in cls.extensions))
+        properties = set(PROPERTIES) | {"ext_" + pp for pp in cls.extensions}
         cls.all_properties = dict(PROPERTIES)
         cls.all_properties.update(cls.extensions)
 
@@ -467,20 +464,20 @@ class MetadataTranslator:
             if property_key not in properties:
                 log.warning(f"Unexpected constant translator for '{property_key}' defined in {cls}")
 
-    def __init__(self, header: Mapping[str, Any], filename: Optional[str] = None) -> None:
+    def __init__(self, header: Mapping[str, Any], filename: str | None = None) -> None:
         self._header = header
         self.filename = filename
-        self._used_cards: Set[str] = set()
+        self._used_cards: set[str] = set()
 
         # Prefix to use for warnings about failed translations
-        self._log_prefix_cache: Optional[str] = None
+        self._log_prefix_cache: str | None = None
 
         # Cache assumes header is read-only once stored in object
-        self._translation_cache: Dict[str, Any] = {}
+        self._translation_cache: dict[str, Any] = {}
 
     @classmethod
     @abstractmethod
-    def can_translate(cls, header: MutableMapping[str, Any], filename: Optional[str] = None) -> bool:
+    def can_translate(cls, header: Mapping[str, Any], filename: str | None = None) -> bool:
         """Indicate whether this translation class can translate the
         supplied header.
 
@@ -501,9 +498,9 @@ class MetadataTranslator:
 
     @classmethod
     def can_translate_with_options(
-        cls, header: Mapping[str, Any], options: Dict[str, Any], filename: Optional[str] = None
+        cls, header: Mapping[str, Any], options: dict[str, Any], filename: str | None = None
     ) -> bool:
-        """Helper method for `can_translate` allowing options.
+        """Determine if a header can be translated with different criteria.
 
         Parameters
         ----------
@@ -537,9 +534,9 @@ class MetadataTranslator:
 
     @classmethod
     def determine_translator(
-        cls, header: Mapping[str, Any], filename: Optional[str] = None
-    ) -> Type[MetadataTranslator]:
-        """Determine a translation class by examining the header
+        cls, header: Mapping[str, Any], filename: str | None = None
+    ) -> type[MetadataTranslator]:
+        """Determine a translation class by examining the header.
 
         Parameters
         ----------
@@ -614,7 +611,7 @@ class MetadataTranslator:
 
     @classmethod
     def fix_header(
-        cls, header: MutableMapping[str, Any], instrument: str, obsid: str, filename: Optional[str] = None
+        cls, header: MutableMapping[str, Any], instrument: str, obsid: str, filename: str | None = None
     ) -> bool:
         """Apply global fixes to a supplied header.
 
@@ -661,7 +658,7 @@ class MetadataTranslator:
         return False
 
     @staticmethod
-    def _construct_log_prefix(obsid: str, filename: Optional[str] = None) -> str:
+    def _construct_log_prefix(obsid: str, filename: str | None = None) -> str:
         """Construct a log prefix string from the obsid and filename.
 
         Parameters
@@ -678,7 +675,7 @@ class MetadataTranslator:
 
     @property
     def _log_prefix(self) -> str:
-        """Standard prefix that can be used for log messages to report
+        """Return standard prefix that can be used for log messages to report
         useful context.
 
         Will be either the filename and obsid, or just the obsid depending
@@ -710,7 +707,7 @@ class MetadataTranslator:
         """
         self._used_cards.update(set(args))
 
-    def cards_used(self) -> FrozenSet[str]:
+    def cards_used(self) -> frozenset[str]:
         """Cards used during metadata extraction.
 
         Returns
@@ -722,9 +719,9 @@ class MetadataTranslator:
 
     @staticmethod
     def validate_value(
-        value: float, default: float, minimum: Optional[float] = None, maximum: Optional[float] = None
+        value: float, default: float, minimum: float | None = None, maximum: float | None = None
     ) -> float:
-        """Validate the supplied value, returning a new value if out of range
+        """Validate the supplied value, returning a new value if out of range.
 
         Parameters
         ----------
@@ -756,7 +753,7 @@ class MetadataTranslator:
         return value
 
     @staticmethod
-    def is_keyword_defined(header: Mapping[str, Any], keyword: Optional[str]) -> bool:
+    def is_keyword_defined(header: Mapping[str, Any], keyword: str | None) -> bool:
         """Return `True` if the value associated with the named keyword is
         present in the supplied header and defined.
 
@@ -784,9 +781,9 @@ class MetadataTranslator:
 
         return True
 
-    def resource_root(self) -> Tuple[Optional[str], Optional[str]]:
-        """Package resource to use to locate correction resources within an
-        installed package.
+    def resource_root(self) -> tuple[str | None, str | None]:
+        """Return package resource to use to locate correction resources within
+        an installed package.
 
         Returns
         -------
@@ -799,7 +796,7 @@ class MetadataTranslator:
         """
         return (self.default_resource_package, self.default_resource_root)
 
-    def search_paths(self) -> List[str]:
+    def search_paths(self) -> list[str]:
         """Search paths to use when searching for header fix up correction
         files.
 
@@ -817,7 +814,7 @@ class MetadataTranslator:
             return [p for p in self.default_search_path]
         return []
 
-    def is_key_ok(self, keyword: Optional[str]) -> bool:
+    def is_key_ok(self, keyword: str | None) -> bool:
         """Return `True` if the value associated with the named keyword is
         present in this header and defined.
 
@@ -834,7 +831,7 @@ class MetadataTranslator:
         return self.is_keyword_defined(self._header, keyword)
 
     def are_keys_ok(self, keywords: Iterable[str]) -> bool:
-        """Are the supplied keys all present and defined?
+        """Are the supplied keys all present and defined?.
 
         Parameters
         ----------
@@ -853,12 +850,12 @@ class MetadataTranslator:
 
     def quantity_from_card(
         self,
-        keywords: Union[str, Sequence[str]],
+        keywords: str | Sequence[str],
         unit: u.Unit,
-        default: Optional[float] = None,
-        minimum: Optional[float] = None,
-        maximum: Optional[float] = None,
-        checker: Optional[Callable] = None,
+        default: float | None = None,
+        minimum: float | None = None,
+        maximum: float | None = None,
+        checker: Callable | None = None,
     ) -> u.Quantity:
         """Calculate a Astropy Quantity from a header card and a unit.
 
@@ -879,7 +876,7 @@ class MetadataTranslator:
         maximum : `float`, optional
             Maximum possible valid value, optional.  If the calculated value
             is above this value, the default value will be used.
-        checker : `function`, optional
+        checker : `~collections.abc.Callable`, optional
             Callback function to be used by the translator method in case the
             keyword is not present.  Function will be executed as if it is
             a method of the translator class.  Running without raising an
@@ -985,7 +982,7 @@ class MetadataTranslator:
         return name
 
     @cache_translation
-    def to_exposure_group(self) -> Optional[str]:
+    def to_exposure_group(self) -> str | None:
         """Return the group label associated with this exposure.
 
         Base class implementation returns the ``exposure_id`` in string
@@ -1129,7 +1126,7 @@ class MetadataTranslator:
 
     @classmethod
     def determine_translatable_headers(
-        cls, filename: str, primary: Optional[MutableMapping[str, Any]] = None
+        cls, filename: str, primary: MutableMapping[str, Any] | None = None
     ) -> Iterator[MutableMapping[str, Any]]:
         """Given a file return all the headers usable for metadata translation.
 
@@ -1140,13 +1137,13 @@ class MetadataTranslator:
         In the base class implementation it is assumed that
         this supplied header is the only useful header for metadata translation
         and it will be returned unchanged if given. This can avoid
-        unnecesarily re-opening the file and re-reading the header when the
+        unnecessarily re-opening the file and re-reading the header when the
         content is already known.
 
         If no header is supplied, a header will be read from the supplied
-        file using `read_basic_metadata_from_file`, allowing it to merge
-        the primary and secondary header of a multi-extension FITS file.
-        Subclasses can read the header from the data file using whatever
+        file using `~.file_helpers.read_basic_metadata_from_file`, allowing it
+        to merge the primary and secondary header of a multi-extension FITS
+        file. Subclasses can read the header from the data file using whatever
         technique is best for that instrument.
 
         Subclasses can return multiple headers and ignore the externally
@@ -1197,7 +1194,7 @@ class MetadataTranslator:
 
 
 def _make_abstract_translator_method(
-    property: str, doc: str, return_typedoc: str, return_type: Type
+    property: str, doc: str, return_typedoc: str, return_type: type
 ) -> Callable:
     """Create a an abstract translation method for this property.
 
@@ -1209,12 +1206,12 @@ def _make_abstract_translator_method(
         Description of the property.
     return_typedoc : `str`
         Type string of this property (used in the doc string).
-    return_type : `class`
+    return_type : `type`
         Type of this property.
 
     Returns
     -------
-    m : `function`
+    m : `~collections.abc.Callable`
         Translator method for this property.
     """
 
@@ -1277,14 +1274,14 @@ class StubTranslator(MetadataTranslator):
 
 
 def _make_forwarded_stub_translator_method(
-    cls: Type[MetadataTranslator], property: str, doc: str, return_typedoc: str, return_type: Type
+    cls: type[MetadataTranslator], property: str, doc: str, return_typedoc: str, return_type: type
 ) -> Callable:
     """Create a stub translation method for this property that calls the
     base method and catches `NotImplementedError`.
 
     Parameters
     ----------
-    cls : `class`
+    cls : `type`
         Class to use when referencing `super()`.  This would usually be
         `StubTranslator`.
     property : `str`
@@ -1293,12 +1290,12 @@ def _make_forwarded_stub_translator_method(
         Description of the property.
     return_typedoc : `str`
         Type string of this property (used in the doc string).
-    return_type : `class`
+    return_type : `type`
         Type of this property.
 
     Returns
     -------
-    m : `function`
+    m : `~collections.abc.Callable`
         Stub translator method for this property.
     """
     method = f"to_{property}"
